/*  File: mod-thrust.cc
 *  Created by Zoltán Nagy on 14 January 2020.
 *  Modified by D. Soper on .... .
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/*   Deductor headers  */
#include <deductor.h>
#include <proc-epajets.h>

/*   Analyser headers  */
#include "analyzer-y23.h"



auto my_jet_module(const deductor_input&)
{
  // auto mdldir = fs::path{"/data1/nagyz/.deductor/4.0/models"};
  // auto mdldir = fs::path{"/home/nagyz/.deductor/4.0/models"};
  auto mdldir = fs::path{"/home/soper/.deductor/4.0/models"};

  /*  Using a previously creating the kernel   */
  deductor<epa> kernel{mdldir, qcd::predefined{}};

  /*    Hard process     */
  auto hard = [=](const model_ref& mdl) -> epajets
  {
    energy<double> Ecm = 10.0_TeV;
    return {mdl, Ecm};
  };
 
  
  /*   Shower options */
  shower_engine_opts opts;
  
  opts.kT_cutoff = 1.0_GeV;
  opts.max_color_suppression = 4u;
  
  /*    starting the calculations for Lambda ordering    */
  kernel(ordering::lambda{}, {"Lambda", opts}, hard, new UserY23{"Cambride-Y23"});


  /*    starting the calculations for kT ordering    */
  kernel(ordering::kT{}, {"kT", opts}, hard, new UserY23{"Cambride-Y23"});


  /*    starting the calculations for angular ordering    */
  kernel(ordering::angular{}, {"Angular", opts}, hard, new UserY23{"Cambride-Y23"});
}

/*   Always export your module functions!   */
export_my_module jets_module = {
  {"LEP-10TeV", my_jet_module}
};

